Crate craftflow_nbt
Source - arrays
- Provides a choice to serialize sequences as
ByteArray, IntArray or LongArray.
- DynNBT
- A structure that can be used to represent any NBT tag dynamically
- Error
- The error type used in this crate.
- from_slice
- Deserializes any NBT structure from a byte slice
and returns the remaining slice together with the value
- from_slice_named
- Deserializes any NBT structure from a byte slice with a name
and returns the remaining slice together with the name and the value
- to_writer
- Serializes any value in the NBT format and returns the number of bytes written.
- to_writer_named
- Serializes any value with a name in the NBT format and returns the number of bytes written.
- Result
- The result type used in this crate