Modules
- Provides a choice to serialize sequences as
ByteArray,IntArrayorLongArray.
Enums
- A structure that can be used to represent any NBT tag dynamically
- The error type used in this crate.
Functions
- Deserializes any NBT structure from a byte slice and returns the remaining slice together with the value
- Deserializes any NBT structure from a byte slice with a name and returns the remaining slice together with the name and the value
- Serializes any value in the NBT format and returns the number of bytes written.
- Serializes any value with a name in the NBT format and returns the number of bytes written.
Type Aliases
- The result type used in this crate